'''version'''
__version__ = '1.6.0'
'''author'''
__author__ = 'Zhenchao Jin'
'''title'''
__title__ = 'SSSegmentation'
'''description'''
__description__ = 'SSSegmentation: An Open Source Supervised Semantic Segmentation Toolbox Based on PyTorch'
'''url'''
__url__ = 'https://github.com/SegmentationBLWX/sssegmentation'
'''email'''
__email__ = 'charlesblwx@gmail.com'
'''license'''
__license__ = 'Apache License 2.0'
'''copyright'''
__copyright__ = 'Copyright 2020-2030 Zhenchao Jin'